CHANGES
=======

1.1.0
-----

Revise for Mathics 9.0.0 release

* Add ``mframe``: is like ``frame`` but for Mathics3-related frame motion
* Add ``mprogram``: is like ``program`` but for Mathics3-related frame
* Add ``abort``: Aborts current Mathics3 command


1.0.0
-----

01/20/2025

First public release. Add trepan3k debugger command functions

* ``mathics3``: Go into a Mathic3 shell
* ``mbacktrace``: backtrace showing interesting Mathics3 frame interpretation
* ``mup``: frame up allowing for jumping to interesting Mathics3 frame
* ``mdown``, frame down allowing for jumping to interesting Mathics3 frame
* ``printelement``: print customized for Mathics3 objects
